## References

1. Wikipedia contributors. Git — Wikipedia, the free encyclopedia. 2023, https://en.wikipedia.org/w/index.php?title=Git&oldid=1177307938.
2. Wikipedia contributors. Digital object identifier — Wikipedia, the free encyclopedia. 2023, https://en.wikipedia.org/w/index.php?title=Digital_object_identifier&oldid=1177404866.
3. Ellerman, E. Castedo. Document succession identifiers. 2024, https://perm.pub/1wFGhvmv8XZfPx0O5Hya2e9AyXo/2.
4. Software Heritage. Intrinsic and extrinsic identifiers. 2020, https://web.archive.org/web/20221019201056/https://www.softwareheritage.org/2020/07/09/intrinsic-vs-extrinsic-identifiers/.
5. Ellerman, E. Castedo. What is a baseprint?. 2023, https://perm.pub/HKSI5NPzMFmgRlb4Vboi71OTKYo/1.